@@ -5,20 +5,13 @@ from datetime import datetime
 from mstr_robotics.helper import str_func
 import pandas as pd
 from typing import Optional
+from IPython.display import display
 
 class open_conn():
 
     def login(self,base_url,project_id=None,*args,**kwargs):
         return get_conn(self,base_url=base_url, project_id=project_id,*args,**kwargs)
-"""
-class prepare_mig_obj():
 
-    def set_env_var(self, conn_det=None, change_log_report=None, change_query=None):
-
-        self.i_datetime = datetime
-        self.conn_det = conn_det
-        self.conn = self.glob.get_conn(conn_det=conn_det, project_id=change_log_report["chg_log_rep_proj_id"])
-"""
 class cubes:
     def __init__(self):
         self.glob = mstr_global
@@ -50,10 +43,11 @@ class bld_short_cuts:
     def run_short_cut_build(self, conn,project_id,short_cut_df,folder_id,df_key_cols_d=None):
         #requiers a pandas data frame with 4 colmuns
         # object_id, object_type, object_name, object_desc
+        self.glob.set_project_id(conn=conn, project_id=project_id)
         if not df_key_cols_d:
-            df_key_cols_d={"object_id":"OBJECT_ID",
-                           "object_type":"OBJECT_TYPE",
-                           "object_name":"OBJECT_NAME",
+            df_key_cols_d={"object_id":"Object@GUID",
+                           "object_type":"OBJECT_TYPE_ID",
+                           "object_name":"Object@Name",
                            "object_desc":"OBJECT_DESC"}
 
         #before adding new short cuts to the shortcut folder, all shortcuts gonna be deleted
@@ -64,6 +58,7 @@ class bld_short_cuts:
         for index, obj in short_cut_df.iterrows():
             #short_cut_url = f'{conn.base_url}/objects/{obj[2]}/type/{str(obj[4])}/shortcuts'
             if obj[df_key_cols_d["object_type"]]!=str(18):
+                print(obj[df_key_cols_d["object_id"]] +"____"+obj[df_key_cols_d["object_type"]])
                 self.bld_short_cut(conn=conn
                                    ,project_id=project_id
                                    ,folder_id=folder_id
@@ -76,7 +71,7 @@ class bld_short_cuts:
             else:
                 print(f'Obect: {obj[2]} is a shortcut. MSTR does not allow short cuts o short cuts,'
                       f' thus they are not supported'  )
-
+        return
     #@logger
     def clean_shortcut_folder(self,conn,project_id,folder_id):
         existing_obj_l = self.glob.get_folder_obj_l(conn=conn, project_id=project_id, folder_id=folder_id)
@@ -109,61 +104,33 @@ class get_change_log:
     #@logger
     def _bld_desc_str(self, all_changes=None):
         desc_str = ""
-        all_changes_sum = all_changes.groupby(["USER_ID", "USER_LOGIN", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE"])[
-            "TRANSACTION_ID"].agg("count").reset_index()
+        all_changes_sum = all_changes.groupby(["Account@GUID", "Account@Login", "Object@GUID", "Object@Name", "OBJECT_TYPE_ID"])[
+            "Timestamp"].agg("count").reset_index()
         for index, s in all_changes_sum.iterrows():
-            desc_str += s["USER_LOGIN"] + " (" + str(s["TRANSACTION_ID"]) + "), "
-        return desc_str
+            desc_str += s["Account@Login"] + " (" + str(s["Timestamp"]) + "), "
+        return self.str._rem_last_char(desc_str,2)
 
     def bld_change_log_shortcut_df(self,conn,change_log_df):
 
-        obj_df = change_log_df.groupby(["USER_ID", "USER_LOGIN", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE"])[
-            "TRANSACTION_ID"].agg("count").reset_index()
+        obj_df = change_log_df.groupby(["Account@GUID", "Account@Login", "Object@GUID", "Object@Name", "OBJECT_TYPE_ID"])[
+            "Timestamp"].agg("count").reset_index()
 
-        obj_df["NEW_OBJECT_NAME"]=""
+        #obj_df["NEW_OBJECT_NAME"]=""
         shortcut_l=[]
         for index, obj in obj_df.iterrows():
             #short_cut_obj=self.glob.get_short_cut_obj(conn=conn, project_id="project_id",object_id=obj["OBJECT_ID"], type=18)
             #builds the Strings for shortCut Name & Descriptions
             #name user_login__object_name__object_guid
             shortcut = []
-            shortcut.append(obj["OBJECT_ID"])
-            shortcut.append(obj["OBJECT_TYPE"])
-            shortcut.append(obj["USER_LOGIN"]+ "__" + obj["OBJECT_NAME"] + "__" + obj["OBJECT_ID"])
-            shortcut.append(self._bld_desc_str(change_log_df.loc[change_log_df["OBJECT_ID"] == obj["OBJECT_ID"]]))
+            shortcut.append(obj["Object@GUID"])
+            shortcut.append(obj["OBJECT_TYPE_ID"])
+            shortcut.append(obj["Account@Login"]+ "__" + obj["Object@Name"] + "__" + obj["Object@GUID"])
+            shortcut.append(self._bld_desc_str(change_log_df.loc[change_log_df["Object@GUID"] == obj["Object@GUID"]]))
             shortcut_l.append(shortcut)
-        shortcut_df=pd.DataFrame(shortcut_l, columns=["OBJECT_ID","OBJECT_TYPE","OBJECT_NAME","OBJECT_DESC"])
+        shortcut_df=pd.DataFrame(shortcut_l, columns=["Object@GUID","OBJECT_TYPE_ID","Object@Name","OBJECT_DESC"])
         return shortcut_df
 
-    def parse_chglog_rep_cols(self,rep_def):
-        #reads out the attributes ot the changelog report
-        cols=[]
-        for r in rep_def.json()["definition"]["grid"]["rows"]:
-            if r["type"] == "attribute":
-                cols.append(r["name"])
-        return  cols
-
-    def chk_chg_log_cols(self,conn,report_id):
-        rep_def=self.rep.get_report_def(conn=conn,report_id=report_id)
-        cols= self.parse_chglog_rep_cols(rep_def)
-        return self.comp_col_chg_log_rep(cols)
-
-    def comp_col_chg_log_rep(self,cols):
-        original_col_order=["TRANSACTION_ID", "PROJECT_ID", "PROJECT_NAME", "USER_ID", "USER_LOGIN", "USERNAME", "COMMENT_VAL", "OBJECT_ID", "OBJECT_NAME", "SUBTYPE", "OBJECT_TYPE", "TRANSACTION_TIMESTAMP", "TRANSACTION_NAME", "TRANSACTION_TYPE", "TRANSACTION_SOURCE", "TRANSACTION_PROJECT_ID"]
-        comp_res={}
-        if original_col_order==cols:
-            comp_res["cols_ok_txt"]="Attributes names and order ok!"
-        else:
-            comp_res["number_of_cols_expected"] =   len(original_col_order)
-            comp_res["number_of_cols_provided"] =   len(cols)
-            comp_res["missing_cols"]=list(set(original_col_order) - set(cols))
-            comp_res["unkwon_cols"]=list(set(cols) - set(original_col_order))
-            comp_res["order_of_cols_expected"] =original_col_order
-            comp_res["order_of_cols_provided"] =cols
-
-        return comp_res
-
-    def chg_rep_to_df(self,conn,prompt_answ):
+    def chg_rep_to_df(self,conn,prompt_answ,chg_log_source="pa"):
 
         instance_id = self.rep.open_Instance(conn=conn, project_id=self.chg_log_rep_proj_id,
                                              report_id=self.chg_log_report_id)
@@ -174,22 +141,29 @@ class get_change_log:
 
         rep_def=self.rep.get_report_def(conn=self.conn,report_id=self.chg_log_report_id)
         cols=self.parse_chglog_rep_cols(rep_def)
-        cols.append("path")
 
-        report_dict = self.rep.report_dict(conn=self.conn,
-                                           report_id=self.chg_log_report_id, instance_id=instance_id)
+        if chg_log_source=="md":
+            report_dict = self.rep.report_dict(conn=self.conn,
+                                               report_id=self.chg_log_report_id, instance_id=instance_id)
+            cols.append("path")
+            report_list = self.read_obj(report_dict)
+            report_df = pd.DataFrame(report_list, columns=cols)
+        if chg_log_source=="pa":
+            report_df = self.rep.report_df(conn=self.conn,
+                                               report_id=self.chg_log_report_id, instance_id=instance_id)
+            report_df['OBJECT_TYPE_ID'] = report_df['OBJECT_TYPE_ID'].apply(lambda x: self.glob.get_obj_type_id(pa_obj_id=x)["OBJECT_TYPE_ID"])
+
 
-        report_list = self.read_obj(report_dict)
-        report_df = pd.DataFrame(report_list, columns=cols)
 
         return report_df
 
-    def get_mig_obj_logs(self,conn,proect_id,from_date,to_date):
+    def get_mig_obj_logs(self,conn,proect_id,from_date,to_date,chg_log_source):
         #get raw data from change logs
         return self.chg_rep_to_df(conn, prompt_answ =self._build_val_answ(
                         chg_log_rep_proj_id=proect_id,
                         chg_log_from_date =from_date,
-                        chg_log_to_date=to_date))
+                        chg_log_to_date=to_date),
+                        chg_log_source=chg_log_source)
         #group by developer /user_id and object
         #generate strings for name and description of the short cuts
         short_cut_df = self.bld_change_log_shortcut_df(conn=self.conn, change_log_df=chg_log_df)
@@ -200,17 +174,17 @@ class get_change_log:
                                           df_key_cols_d=df_key_cols_d)
 
     def read_obj(self, report_dict=None):
-        project_id_ind=1
-        obj_g_ind = 7
-        obj_typ_ind = 10
+        project_id_ind=0
+        obj_g_ind = 5
+        obj_typ_ind = 7
         val_l = []
         all_obj_l = []
         cnt_obj = 0
 
         for o in report_dict:
-            conn=self.glob.set_project_id(conn=self.conn,project_id=self.glob.bld_mstr_obj_guid(o[project_id_ind])) #project_id_ind
+            self.glob.set_project_id(conn=self.conn,project_id=self.glob.bld_mstr_obj_guid(o[project_id_ind])) #project_id_ind
             # self.MstrConn.cHeaders.update({'X-MSTR-ProjectID': o[proj_g_ind] })
-            obj_d = self.glob.get_object_info(conn=conn,
+            obj_d = self.glob.get_object_info(conn=self.conn,
                                               object_id=self.glob.bld_mstr_obj_guid(o[obj_g_ind]), #obj_g_ind
                                               type=o[obj_typ_ind], #obj_typ_ind
                                               project_id=self.glob.bld_mstr_obj_guid(o[project_id_ind]))     #project_id_ind
@@ -232,22 +206,22 @@ class get_change_log:
         return all_obj_l
 
     def bld_chg_l(self,val_l,o,fold_path):
-        val_l.append(o[0])  # transaction_id_ind
-        val_l.append(self.glob.bld_mstr_obj_guid(o[1]))  # project_id_ind
-        val_l.append(o[2])  # project_name_ind
-        val_l.append(self.glob.bld_mstr_obj_guid(o[3]))  # user_id_ind
-        val_l.append(o[4])  # username_ind
-        val_l.append(o[5])  # user_login_ind
-        val_l.append(o[6])  # comment_val_ind
-        val_l.append(self.glob.bld_mstr_obj_guid(o[7]))  # object_id_ind
-        val_l.append(o[8])  # object_name_ind
-        val_l.append(o[9])  # subtype_ind
-        val_l.append(o[10])  # object_type_ind
-        val_l.append(o[11])  # transaction_timestamp_ind
-        val_l.append(o[12])  # transaction_name_ind
-        val_l.append(o[13])  # transaction_type_ind
-        val_l.append(o[14])  # transaction_source_ind
-        val_l.append(self.glob.bld_mstr_obj_guid(o[15]))  # transaction_project_id_ind
+        #val_l.append(o[0])  # transaction_id_ind
+        val_l.append(self.glob.bld_mstr_obj_guid(o[0]))  # project_id_ind
+        val_l.append(o[1])  # project_name_ind
+        val_l.append(self.glob.bld_mstr_obj_guid(o[2]))  # user_id_ind
+        #val_l.append(o[4])  # username_ind
+        val_l.append(o[3])  # user_login_ind
+        val_l.append(o[4])  # comment_val_ind
+        val_l.append(self.glob.bld_mstr_obj_guid(o[5]))  # object_id_ind
+        val_l.append(o[6])  # object_name_ind
+        #val_l.append(o[9])  # subtype_ind
+        val_l.append(o[7])  # object_type_ind
+        val_l.append(o[8])  # transaction_timestamp_ind
+        #val_l.append(o[12])  # transaction_name_ind
+        val_l.append(o[9])  # transaction_type_ind
+        val_l.append(o[10])  # transaction_source_ind
+        #val_l.append(self.glob.bld_mstr_obj_guid(o[15]))  # transaction_project_id_ind
         val_l.append(fold_path)
         return val_l
 
@@ -269,7 +243,53 @@ class get_change_log:
         if prompt_ans:
             prompt_ans = f'{{"prompts":[{prompt_ans}]}}'
         return prompt_ans
+    def parse_chglog_rep_cols(self,rep_def):
+        #reads out the attributes of the changelog report
+        cols=[]
+        for r in rep_def.json()["definition"]["grid"]["rows"]:
+            if r["type"] == "attribute":
+                cols.append(r["name"])
+        return  cols
 
+    def chk_chg_log_cols(self,conn,report_id):
+        rep_def=self.rep.get_report_def(conn=conn,report_id=report_id)
+        cols= self.parse_chglog_rep_cols(rep_def)
+        return self.comp_col_chg_log_rep(cols)
+
+    def comp_col_chg_log_rep(self,cols):
+        #original_col_order=["TRANSACTION_ID", "PROJECT_ID", "PROJECT_NAME", "USER_ID", "USER_LOGIN", "USERNAME", "COMMENT_VAL", "OBJECT_ID", "OBJECT_NAME", "SUBTYPE", "OBJECT_TYPE", "TRANSACTION_TIMESTAMP", "TRANSACTION_NAME", "TRANSACTION_TYPE", "TRANSACTION_SOURCE", "TRANSACTION_PROJECT_ID"]
+        original_col_order = ["PROJECT_ID", "PROJECT_NAME", "USER_ID", "USER_LOGIN",
+                              "COMMENT_VAL", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE",
+                              "TRANSACTION_TIMESTAMP","TRANSACTION_TYPE", "TRANSACTION_SOURCE"]
+        comp_res={}
+        if original_col_order==cols:
+            comp_res["cols_ok_txt"]="Attributes names and order ok!"
+        else:
+            comp_res["number_of_cols_expected"] =   len(original_col_order)
+            comp_res["number_of_cols_provided"] =   len(cols)
+            comp_res["missing_cols"]=list(set(original_col_order) - set(cols))
+            comp_res["unkwon_cols"]=list(set(cols) - set(original_col_order))
+            comp_res["order_of_cols_expected"] =original_col_order
+            comp_res["order_of_cols_provided"] =cols
+
+        return comp_res
+
+class searches:
+
+    def __init__(self):
+        self.glob = mstr_global()
+
+    def used_by_obj_l_rec(self, conn, project_id, obj_id_l):
+        self.glob.set_project_id(conn=conn, project_id=project_id)
+        return list(self.glob.used_by_obj_rec_l(conn=conn,
+                                                project_id=project_id,
+                                                obj_l=obj_id_l)
+                    )
+
+    def bld_df_from_search_result(self, conn, search_l):
+        return self.glob.bld_df_from_search_result(conn=conn, search_l=search_l)
+
+    """ 
     def bld_prompt_obj_where_list(self,obj_l):
         where_str=""
         for o in obj_l:
@@ -300,16 +320,5 @@ class get_change_log:
 
         return obj_l
 
-class searches:
-
-    def __init__(self):
-        self.glob = mstr_global()
-
-    def used_by_obj_l_rec(self,conn,project_id,obj_id_l):
-        return list(self.glob.used_by_obj_rec_l(conn=conn,
-                                                project_id=project_id,
-                                                obj_l=obj_id_l)
-                    )
-    def bld_df_from_search_result(self, conn,search_l):
-        return self.glob.bld_df_from_search_result(conn=conn, search_l=search_l)
 
+"""
\ No newline at end of file
